#!/usr/bin/python
from __future__ import with_statement
import contextlib
import os
import collectd

#set default Values

# Verbose logging on/off. Override in config by specifying 'Verbose'.
VERBOSE_LOGGING = False


def dispatch_value(value, key, type, type_instance=None):
    """dispatch a value"""

    if not type_instance:
        type_instance = key

    log_verbose('Sending value: %s=%s' % (type_instance, value))

    val = collectd.Values(plugin='partitions_state')
    val.type = type
    val.type_instance = type_instance
    val.values = [value]
    val.dispatch()

def log_verbose(msg):
    if not VERBOSE_LOGGING:
        return
    collectd.info('partisions_state plugin [verbose]: %s' % msg)

def configure_callback(conf):
    """Receive configuration block"""
    global DEVICE, MOUNT_POINT, VERBOSE_LOGGING, FS_TYPE
    for node in conf.children:
        if node.key == 'VERBOSE_LOGGING':
            VERBOSE_LOGGING = bool(node.values[0])
        else:
            collectd.warning('inodes_info plugin: Unknown config key: %s.'
                             % node.key)
    log_verbose('Configured with VERBOSE_LOGGING=%s' % (VERBOSE_LOGGING))

def read():
    log_verbose('Read callback called')
    with contextlib.closing(open('/etc/fstab')) as fp:
        for m in fp:
            if not m.startswith('#'):
                if not m.startswith('\n'):
                        val = m.split()
                        dispatch_value(int(os.path.ismount(val[1])), val[1], 'gauge')

# register callbacks
collectd.register_config(configure_callback)
collectd.register_read(read)

