#!/bin/sh
NOCOLOR='\e[0m'         # Text Reset
RED='\e[0;31m'          # Red
GREEN='\e[0;32m'        # Green
## First installation of magicollectd

#PATHS
BASE=/usr/local/monitoring/collectd
mkdir -p $BASE
mkdir -p $BASE/share/collectd/
mkdir -p $BASE/etc/
mkdir -p $BASE/lib/collectd/

# System user collectd
if [ -z "$(cat /etc/passwd | grep collectd)" ]; then
    echo -e "$GREEN creating collectd user... $NOCOLOR"
    useradd collectd -d /usr/local/monitoring -s /sbin/nologin
else
    echo -e "$RED collectd system user is already created. $NOCLOR"
fi

echo -e "$GREEN extracting collectd main and plugins $NOCOLOR"
# Extracting main daemon
mkdir -p $BASE
cd $BASE
tar -xzf $BASE/collectd_main.tar.gz
mv $BASE/main/collectd-debug.tar.gz $BASE/
tar -xzf collectd-debug.tar.gz
rm -rf $BASE/collectd-debug.tar.gz

# identifiying the server
IP=$(ifconfig | grep -E 'inet a?d?d?r?' -m1 | awk '{print $2}' | sed -e 's/[adr:]//g')
if [ -n "$(hostname -s | grep ^srv[0-9].*$)" ]; then          
    perl -p -i -e "s/Hostname.*".*"/Hostname\t \"`hostname -s`\"/g" $BASE/etc/collectd.conf
elif [ -n "$(hostname -f | grep -E .*\.magic.*.f?r?n?e?t?$)" ]; then
    perl -p -i -e "s/Hostname.*".*"/Hostname\t \"`hostname -f`\"/g" $BASE/etc/collectd.conf
else
    perl -p -i -e "s/Hostname.*".*"/Hostname\t \"$IP\"/g" $BASE/etc/collectd.conf
fi

touch $BASE/etc/collectd.d/df.conf
if [ -f " $BASE/sbin/df.pl" ]; then 
    perl $BASE/sbin/df.pl > $BASE/etc/collectd.d/df.conf; 
fi
# rm -rf  $BASE/etc/df.pl

# types.db
STRING_MC="mail_counter value:COUNTER:0:65535"
STRING_N="num value:DERIVE:0:U"
STRING_RL="requestlist value:GAUGE:0:U"
STRING_T="recursion value:GAUGE:0:U"
STRING_R="time value:DERIVE:0:U"
TYPES_DB=$BASE/share/collectd/types.db
if [ -f "$TYPES_DB" ]; then
    if [ -z "$(grep -I \"${STRING_MC}\" $TYPES_DB)" ]; then
        echo "${STRING_MC}" >>${TYPES_DB}
    fi
    if [ -z "$(grep -I \"${STRING_N}\" $TYPES_DB)" ]; then
        echo "${STRING_N}" >>${TYPES_DB}
    fi
    if [ -z "$(grep -I \"${STRING_RL}\" $TYPES_DB)" ]; then
        echo "${STRING_RL}" >>${TYPES_DB}
    fi
    if [ -z "$(grep -I \"${STRING_T}\" $TYPES_DB)" ]; then
        echo "${STRING_T}" >>${TYPES_DB}
    fi
    if [ -z "$(grep -I \"${STRING_R}\" $TYPES_DB)" ]; then
        echo "${STRING_R}" >>${TYPES_DB}
    fi
fi

# Mysql Support
pass=`pwgen -s1 9`
user="support"
db="info"
host="localhost"
mysql_conf="$BASE/etc/magic/mysql.conf"
if [ -f "/root/.rootdbpass" ]; then
    mysql -u root -p`cat /root/.rootdbpass` -e "create database if not exists info;";
    my_com=$(mysql -uroot -p`cat /root/.rootdbpass` -e "show databases;" 2>/dev/null | grep info$)
    echo "[client]" > /root/.my.cnf
    echo "user=root" >> /root/.my.cnf
    rootdbpass=$(cat /root/.rootdbpass)
    echo "password=${rootdbpass}" >> /root/.my.cnf
else
    echo "root/.rootdbpass DOES NOT EXIST. WE ARE NOT CREATING MYSQL Monitoring." 
    echo "Please do it manually. Create a USER=support for DB=support and changes password on mysql.conf"
    my_com=""
fi
my_com2=$(netstat -ntlp | grep mysqld | grep -v grep)
my_socket=$(mysqladmin variables 2>/dev/null | grep socket | sed -e 's/|//g' | grep /var | grep mysql | awk '{print $2}')
my_master=$(mysql -e "SHOW MASTER STATUS;" 2>/dev/null)
my_slave=$(mysql -e "SHOW SLAVE STATUS;" 2>/dev/null)
mysql_thresh_conf="$BASE/etc/magic/thresholds/mysql-threshold.conf"

if [ -n "${my_com}" ]; then
    if [ -f ${mysql_conf} ]; then
        mysql -e  "create database IF NOT EXISTS $db;"
        if [ -z "${my_slave}" ]; then 
            mysql -e "GRANT ALL on $db.* to '$user'@'$host'identified by '$pass';"
            mysql -e "GRANT ALL on $db.* to '$user'@'%'identified by '$pass';"
            mysql -e "GRANT SUPER, REPLICATION CLIENT ON *.* to '$user'@'%' identified by '$pass';"
            mysql -e "GRANT SUPER, REPLICATION CLIENT ON *.* to '$user'@'$host' identified by '$pass';"
            mysql -e "FLUSH PRIVILEGES;"
        else
            echo "This is A MySQL SLAVE machine. Not creating DB user: ${user}"
        fi
        sed   -i "s#public_ip#$host#g" ${mysql_conf}
        sed   -i "s#pass#$pass#g" ${mysql_conf}
        if  [ -n "${my_socket}" ]; then 
            sed   -i "s#/var/run/mysqld/mysqld.sock#${my_socket}#g" ${mysql_conf}
        fi
        if [ -n "${my_master}" ]; then 
            sed -i "s/[fF]alse/true/g" ${mysql_conf}
        fi
    fi
fi
if [ -f ${mysql_conf} ]; then
        #/etc/init.d/mysql restart 2>/dev/null # Do not restart MySQL
        #/etc/init.d/mysqld restart 2>/dev/null
        if [ -z "${my_com2}" ]; then
            echo "Unloading Mysql plugin because no mysqld is running"
            sed -i 's/LoadPlugin/#LoadPlugin/g' ${mysql_conf}
            # TODO disable mysql thresholds
            if [ -f ${mysql_thresh_conf} ]; then
                sed -i -e 's/FailureMin.*/FailureMin 0/g' ${mysql_thresh_conf}
                sed -i -e 's/Persist.*/Persist false/g' ${mysql_thresh_conf}
            fi
        fi
fi
## Riemann Support - protobuf library symlink - 
ln -s /usr/lib64/libprotobuf-c.so.0 /usr/lib64/libprotobuf-c.so.1 2>/dev/null

## Httpd support
httpd_com=$(ls /etc/init.d/httpd 2>/dev/null)
httpd_com2=$(netstat -ntlp | grep -v grep | grep httpd)
httpd_conf="$BASE/etc/magic/thresholds/apache-threshold.conf"
if [ -z "${httpd_com}" ] && [ -z "${httpd_com2}"  ]; then
    echo "httpd not operating -> Disabling httpd threshold"
    if  [ -f "${httpd_conf}" ]; then
        echo "Disabling Apache Plugin and its thresholds"
        sed -i 's/LoadPlugin/#LoadPlugin/g' ${httpd_conf}
        sed -i -e 's/FailureMin.*/FailureMin 0/g' ${httpd_conf}
    fi
fi

# Missing folders
mkdir -p /var/spool/clientmqueue
